@@ -9,11 +9,12 @@
 #ifdef USE_ZLIB
 #include "comp_zlib.h"
 #include "comp_mzlib.h"
-#endif
-#ifdef DEBUG
-#ifdef USE_ZLIB
 #include "comp_mzlib2.h"
 #endif
+#ifdef USE_BZLIB
+#include "comp_bzlib.h"
+#endif
+#ifdef DEBUG
 #include "comp_factor.h"
 #endif
 #include "comp_range.h"
@@ -34,15 +35,19 @@ int (*(algorithms[256]))()={    comp_plain_algo,
 #endif
 				comp_snibble_algo,
 				comp_range_algo,
-#ifdef DEBUG
-				comp_factor_algo,
 #ifdef USE_ZLIB
 				comp_mzlib2_algo,
 #else
 				comp_fail_algo,
 #endif
+#ifdef USE_BZLIB
+				comp_bzlib_algo,
 #else
 				comp_fail_algo,
+#endif
+#ifdef DEBUG
+				comp_factor_algo,
+#else
 				comp_fail_algo,
 #endif
                                 NULL};
@@ -60,16 +65,20 @@ char *algorithm_names[256]={	"Uncompressed",
 #endif
 				"Seminibble Encoding",
 				"Range Encoding",
-#ifdef DEBUG
-				"Factor Compression",
 #ifdef USE_ZLIB
-				"Second Modified Zlib",
+				"Second Modified Zlib Compression",
 #else
 				"Unsupported Algorithm (mzlib2)",
 #endif
+#ifdef USE_BZLIB
+				"Bzip2 Compression",
+#else
+				"Unsupported Algorithm (bzlib)",
+#endif
+#ifdef DEBUG
+				"Factor Compression",
 #else
 				"Unsupported Algorithm (factor)",
-				"Unsupported Algorithm (mzlib2)",
 #endif
 				NULL
 			};
