@@ -43,7 +43,7 @@ int comp_factor_algo(int mode, unsigned char *prev_block, unsigned char *curr_bl
 			return(comp_factor_decompress(prev_block,curr_block,out_block,blk_size));
 			break;
 		default:
-			printf("Unsupported mode: %i\n", mode);
+			fprintf(stderr, "Unsupported mode: %i\n", mode);
 			return(-1);
 	}
 }
@@ -53,6 +53,6 @@ int comp_factor_compress(unsigned char *prev_block, unsigned char *curr_block, c
 }
 
 int comp_factor_decompress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
-	printf("Not yet supported.\n");
+	fprintf(stderr, "Not yet supported.\n");
 	return(0);
 }
