@@ -78,15 +78,21 @@ int comp_text_compress(unsigned char *prev_block, unsigned char *curr_block, cha
 
 	for (i=0;i<blk_size;i++) {
 		byte_buf=(unsigned char) (curr_block[i]-low_byte);
+/*
 		if ((byte_buf>>y)==1) {
 			return(-1);
 		}
+*/
 		bit_buffer_write(byte_buf,y);
 
 		while (bit_buffer_size()>=8) {
 			out_block[x++]=bit_buffer_read(8);
 		}
 	}
+/* 		Remove any less-than-one-byte data */
+	if ((i=bit_buffer_size())!=0) {
+		out_block[x++]=(bit_buffer_read(i)<<(8-i));
+	}
 
 	return(x);
 }
@@ -112,7 +118,7 @@ int comp_text_decompress(unsigned char *prev_block, unsigned char *curr_block, c
 
 	while (1) {
 		if (bit_buffer_size()<y) bit_buffer_write((unsigned char) curr_block[x++],8);
-		out_block[i++]=bit_buffer_read(y);
+		out_block[i++]=(bit_buffer_read(y)+low_byte);
 		if ((x==blk_size) && (bit_buffer_size()<y)) break;
 	}
 
