@@ -45,7 +45,7 @@ extern int optind, opterr, optopt;
 
 int print_help(int argc, char **argv) {
 	fprintf(stderr, "DACT version %i.%i.%i by Roy Keene at Netfuel Design (rkeene@netfueldesign.com).\n\n",DACT_VER_MAJOR,DACT_VER_MINOR,DACT_VER_REVISION);
-	fprintf(stderr, "Usage:\n\t%s [-sdfv[v[v]]Clc] [-e XX] [-b XX] [--] <filename> [outfile]\n\n",argv[0]);
+	fprintf(stderr, "Usage:\n\tdact [-sdfv[v[v]]Clc] [-e XX] [-b XX] [--] <filename> [outfile]\n\n");
 	fprintf(stderr, "  -s\tDisplay statistics about file (Don't compress or decompress.)\n");
 	fprintf(stderr, "  -d\tDecompress instead of compressing.\n");
 	fprintf(stderr, "  -f\tForce overwriting existing files.\n");
@@ -118,7 +118,9 @@ int main(int argc, char **argv) {
 	char option_old=0;
 	char ch;
 	FOUR_BYTES file_size_real=0, file_size, out_file_size, in_magic;
+#ifdef CHECK_VERSION
 	FOUR_BYTES version_latest;
+#endif
 	int stat_cnt[256];
 	int in_fd, out_fd=-1;
 	int i,x=0;
@@ -141,11 +143,28 @@ int main(int argc, char **argv) {
 	option_verbose=1;
 #endif
 
+#ifdef CHECK_VERSION
+/* 
+  This checks for ~/.dact/dact.bin, and executes it
+*/
+#ifndef GO32
+	strcpy(in_filename,getenv("HOME"));
+	strcat(in_filename,"/.dact/dact.bin");
+
+	if (strcmp(argv[0],in_filename)) {
+		if (access(in_filename,X_OK)==0) {
+			argv[0]=in_filename;
+			execv(in_filename,argv);
+		}
+	}
+#endif
+
 	if ((version_latest=is_latest())!=0) {
 		fprintf(stderr, "\033[1mNOTE:\n");
 		fprintf(stderr, "  There is a newer version of DACT: %i.%i.%i\n", version_latest>>16, (version_latest>>8)&0xff, version_latest&0xff);
 		fprintf(stderr, "  http://keene.netfueldesign.com/devel/dact.tar.gz is the latest version.\033[0m\n\n");
 	}
+#endif
 
 #ifdef HAVE_GETOPT
 	while ((ch = getopt(argc,argv,"dfvClshce:b:")) != -1) {
@@ -241,7 +260,8 @@ int main(int argc, char **argv) {
 					strcat(out_filename,".dct");
 				} else {
 // TODO: Fix this, it will break in paths with dots in them, heh.
-					strncpy(out_filename,strtok(in_filename,"."),sizeof(out_filename)-1);
+//					strncpy(out_filename,strtok(in_filename,"."),sizeof(out_filename)-1);
+					strncpy(out_filename,in_filename,strlen(in_filename)-4);
 				}
 			} else {
 				out_fd=STDOUT_FILENO;
