@@ -8,9 +8,7 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <netdb.h>
-#ifdef DEBUG
 #include <stdio.h>
-#endif
 #include "net.h"
 
 
