@@ -36,10 +36,16 @@ chmod 0755 $LFILE
 
 ID=`id | cut -f 2 -d = | cut -f 1 -d "("`
 if [ $ID = 0 ]; then
-  chown root $LFILE
-  chgrp root $LFILE
   cp $LFILE /usr/local/bin
-  mv /usr/local/bin/dact /usr/local/bin/dact.old 2>/dev/null >/dev/null
+  cat /usr/local/bin/dact > /usr/local/bin/dact.old 2>/dev/null
+  rm -f /usr/local/bin/dact
   ln -s /usr/local/bin/$LFILE /usr/local/bin/dact
+  chown root /usr/local/bin/dact.old /usr/local/bin/$LFILE
+  chgrp root /usr/local/bin/dact.old /usr/local/bin/$LFILE
+  chmod 0755  /usr/local/bin/dact.old /usr/local/bin/$LFILE
+else
+  mkdir $HOME/.dact/ 2>/dev/null >/dev/null
+  cp $LFILE $HOME/.dact/dact.bin
 fi
 
+rm $LFILE
